//
//  TPSViewController.m
//  Blocks and Cells
//
//  Created by Bart Jacobs on 15/02/14.
//  Copyright (c) 2014 Tuts+. All rights reserved.
//

#import "TPSViewController.h"

#import "TPSButtonCell.h"

@interface TPSViewController ()

@property (strong, nonatomic) NSArray *dataSource;

@end

@implementation TPSViewController

static NSString *CellIdentifier = @"CellIdentifier";

#pragma mark -
#pragma mark View Life Cycle
- (void)viewDidLoad {
    [super viewDidLoad];
    
    // Setup Data Source
    self.dataSource = @[
                        @{ @"title" : @"Gravity", @"year" : @(2013) },
                        @{ @"title" : @"12 Years a Slave", @"year" : @(2013) },
                        @{ @"title" : @"Before Midnight", @"year" : @(2013) },
                        @{ @"title" : @"American Hustle", @"year" : @(2013) },
                        @{ @"title" : @"Blackfish", @"year" : @(2013) },
                        @{ @"title" : @"Captain Phillips", @"year" : @(2013) },
                        @{ @"title" : @"Nebraska", @"year" : @(2013) },
                        @{ @"title" : @"Rush", @"year" : @(2013) },
                        @{ @"title" : @"Frozen", @"year" : @(2013) },
                        @{ @"title" : @"Star Trek Into Darkness", @"year" : @(2013) },
                        @{ @"title" : @"The Conjuring", @"year" : @(2013) },
                        @{ @"title" : @"Side Effects", @"year" : @(2013) },
                        @{ @"title" : @"The Attack", @"year" : @(2013) },
                        @{ @"title" : @"The Hobbit", @"year" : @(2013) },
                        @{ @"title" : @"We Are What We Are", @"year" : @(2013) },
                        @{ @"title" : @"Something in the Air", @"year" : @(2013) }
                        ];
}

#pragma mark -
#pragma mark Table View Data Source Methods
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return self.dataSource ? 1 : 0;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource ? self.dataSource.count : 0;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    TPSButtonCell *cell = (TPSButtonCell *)[tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
    // Fetch Item
    NSDictionary *item = [self.dataSource objectAtIndex:indexPath.row];
    
    // Configure Table View Cell
    [cell.titleLabel setText:[NSString stringWithFormat:@"%@ (%@)", item[@"title"], item[@"year"]]];
    // [cell.actionButton addTarget:self action:@selector(didTapButton:) forControlEvents:UIControlEventTouchUpInside];
    
    [cell setDidTapButtonBlock:^(id sender) {
        NSLog(@"%@", item[@"title"]);
    }];
    
    return cell;
}

- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath {
    return NO;
}

- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath {
    return NO;
}

#pragma mark -
#pragma mark Actions
/*
// How Not To Do It
- (void)didTapButton:(id)sender {
    // Find Table View Cell
    // UITableViewCell *cell = (UITableViewCell *)[[[sender superview] superview] superview]; // iOS 7
    UITableViewCell *cell = (UITableViewCell *)[[sender superview] superview]; // iOS 6
    
    // Infer Index Path
    NSIndexPath *indexPath = [self.tableView indexPathForCell:cell];
    
    // Fetch Item
    NSDictionary *item = [self.dataSource objectAtIndex:indexPath.row];
    
    // Log to Console
    NSLog(@"%@", item[@"title"]);
}
*/

/*
// A Better Solution
- (void)didTapButton:(id)sender {
    // Cast Sender to UIButton
    UIButton *button = (UIButton *)sender;
    
    // Find Point in Superview
    CGPoint pointInSuperview = [button.superview convertPoint:button.center toView:self.tableView];
    
    // Infer Index Path
    NSIndexPath *indexPath = [self.tableView indexPathForRowAtPoint:pointInSuperview];
    
    // Fetch Item
    NSDictionary *item = [self.dataSource objectAtIndex:indexPath.row];
    
    // Log to Console
    NSLog(@"%@", item[@"title"]);
}
*/

@end
